"""
Standardized Report format for the result of running Pedal CLI's Stats mode.


Need to capture
    Each submission
        Errors
        Stdout?
        Feedback Functions generated
            All the usual fields
        Final Feedback chosen
    The ICS used on it
    Any metadata surrounding that
        User/Assignment/Course
"""


class StatReport:
    pass